# AUTOGENERATED! DO NOT EDIT! File to edit: notebooks/HUD.ipynb (unless otherwise specified).

__all__ = ['df', 'cdf', 'cdf', 'cdf', 'cdf2', 'cdf2']

# Cell
import pandas as pd

df = pd.read_csv("hcv_2019_BCityonly.csv");

# Cell
import numpy as np
df['tract'] = df['Code'].astype(str).str[4:].astype(np.int64)
df['tract']

# Cell
from dataplay.acsDownload import retrieve_acs_data
cdf = retrieve_acs_data(state, county, tract, tableId, year, saveAcs).reset_index()[['B25003_003E_Total:_Renter_occupied', 'tract']]

# Cell
df['B25003_003E_Total:_Renter_occupied'] = df.merge(cdf, left_on='tract', right_on='tract')['B25003_003E_Total:_Renter_occupied']
df.head()

# Cell
# Match Tract to CSA
df['CSA'] = df.merge(crosswalk, left_on='Code', right_on='GEOID10')['CSA2010']

# Cell
from math import floor
cdf = df.merge(crosswalk, left_on='Code', right_on='GEOID2010', how='left')
cdf["TRACT2010"] = cdf["TRACT2010"].fillna(0.0).astype(int)

# TRACTCE10 GEOID10 NAME10 CSA
cdf['TRACTCE10'] = cdf['TRACT2010']
cdf['GEOID10'] = cdf['Code']
cdf['CSA'] = cdf['CSA2010']

cdf = cdf.drop(columns=['TRACT2010', 'GEOID2010', 'Code', 'CSA2010', 'TRACT2010' ], axis=1)

# Cell
cdf2 = cdf.merge(cw2, left_on='TRACTCE10', right_on='TRACT', how='left')
cdf2['NAME10'] = cdf2['NEIGHBORHOOD']
cdf2 = cdf2.drop(columns=['TRACT', 'NEIGHBORHOOD'], axis=1)
cdf2.head(1)

# Cell
 cd3 = cdf2[[
           'NAME10',
           'TRACTCE10', 'CSA', 'GEOID10',
           'Summary level', 'Program label', 'Program', 'Sub-program', 'Name',
       'Subsidized units available', '% Occupied', '# Reported',
       '% Reported', 'Average months since report', '% moved in past year',
       'Number of people per unit', 'Number of people: total',
       'Average Family Expenditure per month ($$)',
       'Average HUD Expenditure per month ($$)', 'Household income per year',
       'Household income per year per person', '% $1 - $4,999',
       '% $5,000 - $9,999', '% $10,000 - $14,999', '% $15,000 - $19,999',
       '% $20,000 or more',
       '% Households where wages are major source of income',
       '% Households where welfare is major source of income',
       '% Households with other major sources of income',
       '% of local median (Household income)', '% very low income',
       '% extremely low income', '% 2+ adults with children',
       '% 1 adult with children', '% female head',
       '% female head with children',
       '% with disability, among Head, Spouse, Co-head, aged 61 years or less',
       '% with disability, among Head, Spouse, Co-head, aged 62 years or older',
       '% with disability, among all persons in households',
       '% 24 years or less (Head or spouse)',
       '% 25 to 49 years (Head or spouse)', '% 51 to 60 (Head or spouse)',
       '% 62 or more (Head or spouse)', '% 85 or more (Head or spouse)',
       '% Minority', '%Black Non-Hispanic', ' %Black Hispanic',
       '%Native American Non-Hispanic',
       '%Asian or Pacific Islander Non-Hispanic', '% Hispanic',
       'Average months on waiting list', 'Average months since moved in',
       '% with utility allowance', 'Average utility allowance $$',
       '% 0 - 1 bedrooms:', '% 2 bedrooms', '% 3+ bedrooms', '% Overhoused',
       '% in poverty (Census tract)', '% minority (Census tract)',
       '% single family owners (Census tract)', 'Congressional District',
       'CBSA', 'PLACE', 'Latitude', 'Longitude', 'State', 'PHA Total Units',
       'HA category']]


# AUTOGENERATED! DO NOT EDIT! File to edit: notebooks/City_Liquor_Board_Permits.ipynb (unless otherwise specified).

__all__ = ['liquor', 'fin']

# Cell
def liquor(df, csa, yr):

  # Create the Numerator
  liquor = df.copy()

  liquor = liquor[
    ( liquor['License'].str.contains('LA|LA-2|LAS|LBD7|WA|WAS', regex=True) )
  ]

  liquor['count'] = 1
  liquor = liquor.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  liquor = csa.merge( liquor, left_on='CSA2010', right_on='CSA2010', how='outer' )
  liquor.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)
  # Baltimoire has records not in the
  liquor.at[55,'count']=liquor['count'].sum()
  # Perform the calculation
  liquor['109-liquor'+year] = liquor['count'] / liquor['tpop10'] * 1000

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/Liquor/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  prevYear = 'liquor'+ str( int(year) - 1 )
  if prevYear in compareYears.columns:
    liquor = liquor.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    liquor['change'] = liquor['109-liquor'+year] - liquor[ prevYear ]
    liquor['percentChange'] = liquor['change' ] / liquor[ prevYear ] * 100
    liquor['change'] = liquor['change'].apply(lambda x: "{:.2f}".format(x) )
  print( 'Records Matching Query: ', liquor.size / len(liquor.columns) )
  return liquor

fin = liquor(liquordf, csa, year)
fin.to_csv('109-liquor'+year+'.csv', index=False)
fin.head(60)


# AUTOGENERATED! DO NOT EDIT! File to edit: notebooks/BCPSS_Schools.ipynb (unless otherwise specified).

__all__ = ['eattend', 'mattend', 'hsattend', 'aastud', 'wstud', 'hstud', 'abse', 'absmd', 'abshd', 'drop', 'compl',
           'sclsw', 'eenrol', 'menrol', 'hsenrol']

# Cell
def eattend(df, csa, yr):

  # Create the Numerator
  eattend = df.copy()
  eattend = eattend[ eattend['grade'].str.contains('^1$|^2$|^3$|^4$|^5$', regex=True)  & (eattend['daysattend'] > 1) ]

  eattend['count'] = 1
  eattend = eattend.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  eattend = csa.merge( eattend, left_on='CSA2010', right_on='CSA2010', how='outer' )
  eattend.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)
  # Baltimoire has records not in the
  eattend.at[55,'count']=eattend['count'].sum()
  # Perform the calculation
  eattend['66-eattend'+year] = eattend['count']

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/Eattend/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = 'eattend'+ str( int(year) - goback )
  if prevYear in compareYears.columns:
    eattend = eattend.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    eattend['change'] = eattend['66-eattend'+year] - eattend[ prevYear ]
    eattend['percentChange'] = eattend['change' ] / eattend[ prevYear ] * 100
    eattend['change'] = eattend['change'].apply(lambda x: "{:.2f}".format(x) )
  print( 'Records Matching Query: ', eattend.size / len(eattend.columns) )
  return eattend.drop(columns=['daysattend', 'SchoolSwitcherFlag', 'wleavecode', 'daysabsent', 'race_AIAN', 'race_asian', 'race_AA', 'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def mattend(df, csa, yr):

  # Create the Numerator
  mattend = df.copy()

  mattend = mattend[ mattend['grade'].str.contains('^6$|^7$|^8$', regex=True)  & (mattend['daysattend'] > 1) ]

  mattend['count'] = 1
  mattend = mattend.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  mattend = csa.merge( mattend, left_on='CSA2010', right_on='CSA2010', how='outer' )
  mattend.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)
  # Baltimoire has records not in the
  mattend.at[55,'count']=mattend['count'].sum()
  # Perform the calculation
  mattend['67-mattend'+year] = mattend['count']

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/Mattend/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = 'mattend'+ str( int(year) - goback )
  if prevYear in compareYears.columns:
    mattend = mattend.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    mattend['change'] = mattend['67-mattend'+year] - mattend[ prevYear ]
    mattend['percentChange'] = mattend['change' ] / mattend[ prevYear ] * 100
    mattend['change'] = mattend['change'].apply(lambda x: "{:.2f}".format(x) )
  print( 'Records Matching Query: ', mattend.size / len(mattend.columns) )
  return mattend.drop(columns=['daysattend', 'SchoolSwitcherFlag', 'wleavecode', 'daysabsent', 'race_AIAN', 'race_asian', 'race_AA', 'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def hsattend(df, csa, yr):

  # Create the Numerator
  hsattend = df.copy()

  hsattend = hsattend[ hsattend['grade'].str.contains('^9$|^10$|^11$|^12$', regex=True)  & (hsattend['daysattend'] > 1) ]

  hsattend['count'] = 1
  hsattend = hsattend.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  hsattend = csa.merge( hsattend, left_on='CSA2010', right_on='CSA2010', how='outer' )
  hsattend.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)
  # Baltimoire has records not in the
  hsattend.at[55,'count']=hsattend['count'].sum()
  # Perform the calculation
  hsattend['68-hsattend'+year] = hsattend['count']

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/Hsattend/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = 'hsattend'+ str( int(year) - goback )
  if prevYear in compareYears.columns:
    hsattend = hsattend.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    hsattend['change'] = hsattend['68-hsattend'+year] - hsattend[ prevYear ]
    hsattend['percentChange'] = hsattend['change' ] / hsattend[ prevYear ] * 100
    hsattend['change'] = hsattend['change'].apply(lambda x: "{:.2f}".format(x) )
  print( 'Records Matching Query: ', hsattend.size / len(hsattend.columns) )
  return hsattend.drop(columns=['daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def aastud(df, csa, yr):
  df['count'] = 1

  # Create the Denominator
  denom = df.copy()
  denom['grade'] = denom['grade'].apply(pd.to_numeric, errors='coerce')
  denom = denom[ (denom['daysattend'] > 1) & (denom['grade'] < 13) ]

  # Create the Numerator
  numer = denom[ (denom['race_AA'] > 0 ) & (denom['hispani_la'] == 'N') ]

  id = '70'
  shortname = 'aastud'

  # Group by CSA
  numer = numer.groupby('CSA2010').sum(numeric_only=True)
  denom = denom.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  numer = csa.merge( numer, left_on='CSA2010', right_on='CSA2010', how='outer' )
  denom = csa.merge( denom, left_on='CSA2010', right_on='CSA2010', how='outer' )
  numer.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)
  numer['denomCount'] = denom['count']

  # Do after sortViaCsaMerge to get index right. False records would show underneath it but still get added to the sum.
  numer.at[55,'count']=numer['count'].sum()
  numer.at[55,'denomCount']=numer['denomCount'].sum()

  # Perform the calculation
  numer[id+'-'+shortname+year] = numer['count'] / numer['denomCount'] * 100

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/"+shortname.capitalize()+"/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = shortname+ str( int(year) - goback )
  if prevYear in compareYears.columns:
    numer = numer.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    numer['change'] = numer[id+'-'+shortname+year] - numer[ prevYear ]
    numer['percentChange'] = numer['change' ] / numer[ prevYear ] * 100
    numer['change'] = numer['change'].apply(lambda x: "{:.2f}".format(x) )
    print( 'Records Matching Query: ', numer.size / len(numer.columns) )
  return numer.drop(columns=['daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def wstud(df, csa, yr):
  id = '71'
  shortname = 'wstud'
  df['count'] = 1

  # Create the Denominator
  denom = df.copy()
  denom['grade'] = denom['grade'].apply(pd.to_numeric, errors='coerce')
  denom = denom[ (denom['daysattend'] > 1) & (denom['grade'] < 13) ]

  # Create the Numerator
  numer = denom[ (denom['race_white'] > 0 ) & (denom['hispani_la'] == 'N') ]

  id = '71'
  shortname = 'wstud'

  # Group by CSA
  numer = numer.groupby('CSA2010').sum(numeric_only=True)
  denom = denom.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  numer = csa.merge( numer, left_on='CSA2010', right_on='CSA2010', how='outer' )
  denom = csa.merge( denom, left_on='CSA2010', right_on='CSA2010', how='outer' )
  numer.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)
  numer['denomCount'] = denom['count']

  # Do after sortViaCsaMerge to get index right. False records would show underneath it but still get added to the sum.
  numer.at[55,'count']=numer['count'].sum()
  numer.at[55,'denomCount']=numer['denomCount'].sum()

  # Perform the calculation
  numer[id+'-'+shortname+year] = numer['count'] / numer['denomCount'] * 100

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/"+shortname.capitalize()+"/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = shortname + str( int(year) - goback )
  if prevYear in compareYears.columns:
    numer = numer.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    numer['change'] = numer[id+'-'+shortname+year] - numer[ prevYear ]
    numer['percentChange'] = numer['change' ] / numer[ prevYear ] * 100
    numer['change'] = numer['change'].apply(lambda x: "{:.2f}".format(x) )
    print( 'Records Matching Query: ', numer.size / len(numer.columns) )
  return numer.drop(columns=['daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def hstud(df, csa, yr):
  df['count'] = 1

  # Create the Denominator
  denom = df.copy()
  denom['grade'] = denom['grade'].apply(pd.to_numeric, errors='coerce')
  denom = denom[ (denom['daysattend'] > 1) & (denom['grade'] < 13) ]

  # Create the Numerator
  numer = denom[ (denom['hispani_la'] == 'Y') ]

  id = '72'
  shortname = 'hstud'

  # Group by CSA
  numer = numer.groupby('CSA2010').sum(numeric_only=True)
  denom = denom.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  numer = csa.merge( numer, left_on='CSA2010', right_on='CSA2010', how='outer' )
  denom = csa.merge( denom, left_on='CSA2010', right_on='CSA2010', how='outer' )
  numer.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)
  numer['denomCount'] = denom['count']

  # Do after sortViaCsaMerge to get index right. False records would show underneath it but still get added to the sum.
  numer.at[55,'count']=numer['count'].sum()
  numer.at[55,'denomCount']=numer['denomCount'].sum()

  # Perform the calculation
  numer[id+'-'+shortname+year] = numer['count'] / numer['denomCount'] * 100

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/"+shortname.capitalize()+"/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = shortname + str( int(year) - goback )
  if prevYear in compareYears.columns:
    numer = numer.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    numer['change'] = numer[id+'-'+shortname+year] - numer[ prevYear ]
    numer['percentChange'] = numer['change' ] / numer[ prevYear ] * 100
    numer['change'] = numer['change'].apply(lambda x: "{:.2f}".format(x) )
    print( 'Records Matching Query: ', numer.size / len(numer.columns) )
  return numer.drop(columns=['daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def abse(df, csa, yr):
  df['count'] = 1

  # Create the Denominator
  denom = df.copy()
  denom = denom[ denom['grade'].str.contains('^1$|^2$|^3$|^4$|^5$', regex=True)  & (denom['daysattend'] > 1) ]

  # Create the Numerator
  numer = denom[ (denom['daysabsent'] > 200 ) ]

  id = '73'
  shortname = 'abse'

  # Group by CSA
  numer = numer.groupby('CSA2010').sum(numeric_only=True)
  denom = denom.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  numer = csa.merge( numer, left_on='CSA2010', right_on='CSA2010', how='outer' )
  denom = csa.merge( denom, left_on='CSA2010', right_on='CSA2010', how='outer' )
  numer.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)
  denom.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)

  numer.drop(columns=['tpop10', 'EnrollmentFlag', 'daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate']).to_csv(id+'-'+shortname+year+'_numer.csv', index=False)
  denom.drop(columns=['tpop10', 'EnrollmentFlag', 'daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate']).to_csv(id+'-'+shortname+year+'_denom.csv', index=False)

  numer['denomCount'] = denom['count']

  # Do after sortViaCsaMerge to get index right. False records would show underneath it but still get added to the sum.
  numer.at[55,'count']=numer['count'].sum()
  numer.at[55,'denomCount']=numer['denomCount'].sum()

  # Perform the calculation
  numer[id+'-'+shortname+year] = numer['count'] / numer['denomCount'] * 100

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/"+shortname.capitalize()+"/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = shortname + str( int(year) - goback )
  if prevYear in compareYears.columns:
    numer = numer.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    numer['change'] = numer[id+'-'+shortname+year] - numer[ prevYear ]
    numer['percentChange'] = numer['change' ] / numer[ prevYear ] * 100
    numer['change'] = numer['change'].apply(lambda x: "{:.2f}".format(x) )
    print( 'Records Matching Query: ', numer.size / len(numer.columns) )
  return numer.drop(columns=['daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def absmd(df, csa, yr):
  df['count'] = 1

  # Create the Denominator
  denom = df.copy()
  denom = denom[ denom['grade'].str.contains('^6$|^7$|^8$', regex=True)  & (denom['daysattend'] > 1) ]

  # Create the Numerator
  numer = denom[ (denom['daysabsent'] > 200 ) ]

  id = '74'
  shortname = 'absmd'

  # Group by CSA
  numer = numer.groupby('CSA2010').sum(numeric_only=True)
  denom = denom.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  numer = csa.merge( numer, left_on='CSA2010', right_on='CSA2010', how='outer' )
  denom = csa.merge( denom, left_on='CSA2010', right_on='CSA2010', how='outer' )
  numer.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)
  denom.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)

  numer.drop(columns=['tpop10', 'EnrollmentFlag', 'daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate']).to_csv(id+'-'+shortname+year+'_numer.csv', index=False)
  denom.drop(columns=['tpop10', 'EnrollmentFlag', 'daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate']).to_csv(id+'-'+shortname+year+'_denom.csv', index=False)

  numer['denomCount'] = denom['count']

  # Do after sortViaCsaMerge to get index right. False records would show underneath it but still get added to the sum.
  numer.at[55,'count']=numer['count'].sum()
  numer.at[55,'denomCount']=numer['denomCount'].sum()

  # Perform the calculation
  numer[id+'-'+shortname+year] = numer['count'] / numer['denomCount'] * 100

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/"+shortname.capitalize()+"/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = shortname + str( int(year) - goback )
  if prevYear in compareYears.columns:
    numer = numer.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    numer['change'] = numer[id+'-'+shortname+year] - numer[ prevYear ]
    numer['percentChange'] = numer['change' ] / numer[ prevYear ] * 100
    numer['change'] = numer['change'].apply(lambda x: "{:.2f}".format(x) )
    print( 'Records Matching Query: ', numer.size / len(numer.columns) )
  return numer.drop(columns=['daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def abshd(df, csa, yr):
  df['count'] = 1

  # Create the Denominator
  denom = df.copy()
  denom = denom[ denom['grade'].str.contains('^9$|^10$|^11$|^12$', regex=True)  & (denom['daysattend'] > 1) ]

  # Create the Numerator
  numer = denom[ (denom['daysabsent'] > 200 ) ]

  id = '75'
  shortname = 'abshs'

  # Group by CSA
  numer = numer.groupby('CSA2010').sum(numeric_only=True)
  denom = denom.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  numer = csa.merge( numer, left_on='CSA2010', right_on='CSA2010', how='outer' )
  denom = csa.merge( denom, left_on='CSA2010', right_on='CSA2010', how='outer' )
  numer.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)
  denom.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)

  numer.drop(columns=['tpop10', 'EnrollmentFlag', 'daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate']).to_csv(id+'-'+shortname+year+'_numer.csv', index=False)
  denom.drop(columns=['tpop10', 'EnrollmentFlag', 'daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate']).to_csv(id+'-'+shortname+year+'_denom.csv', index=False)

  numer['denomCount'] = denom['count']

  # Do after sortViaCsaMerge to get index right. False records would show underneath it but still get added to the sum.
  numer.at[55,'count']=numer['count'].sum()
  numer.at[55,'denomCount']=numer['denomCount'].sum()

  # Perform the calculation
  numer[id+'-'+shortname+year] = numer['count'] / numer['denomCount'] * 100

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/"+shortname.capitalize()+"/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = shortname + str( int(year) - goback )
  if prevYear in compareYears.columns:
    numer = numer.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    numer['change'] = numer[id+'-'+shortname+year] - numer[ prevYear ]
    numer['percentChange'] = numer['change' ] / numer[ prevYear ] * 100
    numer['change'] = numer['change'].apply(lambda x: "{:.2f}".format(x) )
    print( 'Records Matching Query: ', numer.size / len(numer.columns) )
  return numer.drop(columns=['daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def drop(df, csa, yr):
  df['count'] = 1

  # Create the Denominator
  denom = df.copy()
  denom = denom[ denom['grade'].str.contains('^9$|^10$|^11$|^12$', regex=True)  & (denom['daysattend'] > 1) ]

  # Create the Numerator
  denom['wleavecode'] = denom['wleavecode'].astype(str)
  numer = denom[ ( denom['wleavecode'].str.contains('30|31|32|33|34|35|36|37|38|39|41|42|44|46|50|71|85', regex=True) ) ]

  id = '91'
  shortname = 'drop'

  # Group by CSA
  numer = numer.groupby('CSA2010').sum(numeric_only=True)
  denom = denom.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  numer = csa.merge( numer, left_on='CSA2010', right_on='CSA2010', how='outer' )
  denom = csa.merge( denom, left_on='CSA2010', right_on='CSA2010', how='outer' )
  numer.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)
  numer['denomCount'] = denom['count']

  # Do after sortViaCsaMerge to get index right. False records would show underneath it but still get added to the sum.
  numer.at[55,'count']=numer['count'].sum()
  numer.at[55,'denomCount']=numer['denomCount'].sum()

  # Perform the calculation
  numer[id+'-'+shortname+year] = numer['count'] / numer['denomCount'] * 100

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/"+shortname.capitalize()+"/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = shortname + str( int(year) - goback )
  if prevYear in compareYears.columns:
    numer = numer.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    numer['change'] = numer[id+'-'+shortname+year] - numer[ prevYear ]
    numer['percentChange'] = numer['change' ] / numer[ prevYear ] * 100
    numer['change'] = numer['change'].apply(lambda x: "{:.2f}".format(x) )
    print( 'Records Matching Query: ', numer.size / len(numer.columns) )
  return numer.drop(columns=['daysattend', 'SchoolSwitcherFlag',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def compl(df, csa, yr):
  df['count'] = 1

  # Create the Denominator
  denom = df.copy()
  denom = denom[ denom['grade'].str.contains('^12$', regex=True)  & (denom['daysattend'] > 1) ]

  # Create the Numerator
  denom['wleavecode'] = denom['wleavecode'].astype(str)
  numer = denom[ ( denom['wleavecode'].str.contains('85|62|10|60', regex=True) ) ]

  id = '92'
  shortname = 'compl'

  # Group by CSA
  numer = numer.groupby('CSA2010').sum(numeric_only=True)
  denom = denom.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  numer = csa.merge( numer, left_on='CSA2010', right_on='CSA2010', how='outer' )
  denom = csa.merge( denom, left_on='CSA2010', right_on='CSA2010', how='outer' )
  numer.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)
  numer['denomCount'] = denom['count']

  # Do after sortViaCsaMerge to get index right. False records would show underneath it but still get added to the sum.
  numer.at[55,'count']=numer['count'].sum()
  numer.at[55,'denomCount']=numer['denomCount'].sum()

  # Perform the calculation
  numer[id+'-'+shortname+year] = numer['count'] / numer['denomCount'] * 100

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/"+shortname.capitalize()+"/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = shortname + str( int(year) - goback )
  if prevYear in compareYears.columns:
    numer = numer.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    numer['change'] = numer[id+'-'+shortname+year] - numer[ prevYear ]
    numer['percentChange'] = numer['change' ] / numer[ prevYear ] * 100
    numer['change'] = numer['change'].apply(lambda x: "{:.2f}".format(x) )
    print( 'Records Matching Query: ', numer.size / len(numer.columns) )
  return numer.drop(columns=['daysattend', 'SchoolSwitcherFlag',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def sclsw(df, denomdf, csa, yr):
  df['count'] = 1
  denomdf['count'] = 1

  # Create the Denominator
  denom = denomdf.copy() #.sort_values('enterdate', ascending=False).drop_duplicates(['std_number'])
  denom = denom[ (denom['daysattend'] > 1) ]

  # Create the Numerator
  numer = df.copy()
  numer = numer[ (numer['daysattend'] > 1) ]

  id = '94'
  shortname = 'sclsw'

  # Group by CSA
  numer = numer.groupby('CSA2010').sum(numeric_only=True)
  denom = denom.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  numer = csa.merge( numer, left_on='CSA2010', right_on='CSA2010', how='outer' )
  denom = csa.merge( denom, left_on='CSA2010', right_on='CSA2010', how='outer' )
  numer.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)
  numer['denomCount'] = denom['count']

  # Do after sortViaCsaMerge to get index right. False records would show underneath it but still get added to the sum.
  numer.at[55,'count']=numer['count'].sum()
  numer.at[55,'denomCount']=numer['denomCount'].sum()

  # Perform the calculation
  numer[id+'-'+shortname+year] = numer['count'] / numer['denomCount'] * 100

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/"+shortname.capitalize()+"/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = shortname + str( int(year) - goback )
  if prevYear in compareYears.columns:
    numer = numer.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    numer['change'] = numer[id+'-'+shortname+year] - numer[ prevYear ]
    numer['percentChange'] = numer['change' ] / numer[ prevYear ] * 100
    numer['change'] = numer['change'].apply(lambda x: "{:.2f}".format(x) )
    print( 'Records Matching Query: ', numer.size / len(numer.columns) )
  return numer.drop(columns=['daysattend', 'SchoolSwitcherFlag',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def eenrol(df, csa, yr):
  df['count'] = 1

  # Create the Numerator
  numer = df.copy() # .sort_values('enterdate', ascending=False).drop_duplicates(['std_number'])
  numer = numer[ numer['grade'].str.contains('^1$|^2$|^3$|^4$|^5$', regex=True) ]

  id = '195'
  shortname = 'eenrol'

  # Group by CSA
  numer = numer.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  numer = csa.merge( numer, left_on='CSA2010', right_on='CSA2010', how='outer' )
  numer.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)

  # Do after sortViaCsaMerge to get index right. False records would show underneath it but still get added to the sum.
  numer.at[55,'count']=numer['count'].sum()

  # Perform the calculation
  numer[id+'-'+shortname+year] = numer['count']

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/"+shortname.capitalize()+"/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = shortname + str( int(year) - goback )
  if prevYear in compareYears.columns:
    numer = numer.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    numer['change'] = numer[id+'-'+shortname+year] - numer[ prevYear ]
    numer['percentChange'] = numer['change' ] / numer[ prevYear ] * 100
    numer['change'] = numer['change'].apply(lambda x: "{:.2f}".format(x) )
    print( 'Records Matching Query: ', numer.size / len(numer.columns) )
  return numer.drop(columns=['daysattend', 'SchoolSwitcherFlag',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def menrol(df, csa, yr):
  df['count'] = 1

  # Create the Denominator
  numer = df.copy()
  numer = numer[ numer['grade'].str.contains('^6$|^7$|^8$', regex=True) ]

  id = '196'
  shortname = 'menrol'

  # Group by CSA
  numer = numer.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  numer = csa.merge( numer, left_on='CSA2010', right_on='CSA2010', how='outer' )
  numer.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)

  # Do after sortViaCsaMerge to get index right. False records would show underneath it but still get added to the sum.
  numer.at[55,'count']=numer['count'].sum()

  # Perform the calculation
  numer[id+'-'+shortname+year] = numer['count']

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/"+shortname.capitalize()+"/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = shortname + str( int(year) - goback )
  if prevYear in compareYears.columns:
    numer = numer.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    numer['change'] = numer[id+'-'+shortname+year] - numer[ prevYear ]
    numer['percentChange'] = numer['change' ] / numer[ prevYear ] * 100
    numer['change'] = numer['change'].apply(lambda x: "{:.2f}".format(x) )
    print( 'Records Matching Query: ', numer.size / len(numer.columns) )
  return numer.drop(columns=['daysattend', 'SchoolSwitcherFlag', 'wleavecode',
               'daysabsent', 'race_AIAN', 'race_asian', 'race_AA',
               'race_NHPI', 'race_white', 'std_number', 'enterdate'])

# Cell
def hsenrol(df, csa, yr):
  df['count'] = 1

  # Create the Denominator
  numer = df.copy() #.sort_values('enterdate', ascending=False).drop_duplicates(['std_number'])
  numer = numer[ numer['grade'].str.contains('^9$|^10$|^11$|^12$', regex=True) ]
  print( numer['grade'].unique() )

  id = '197'
  shortname = 'hsenrol'

  # Group by CSA
  numer = numer.groupby('CSA2010').sum(numeric_only=True)

  # Make sure ALL csas and BaltimoreCity are included and sorted.
  numer = csa.merge( numer, left_on='CSA2010', right_on='CSA2010', how='outer' )
  numer.drop( columns=['geometry', 'Shape__Length','Shape__Area'], inplace=True)

  # Bcity is the sum of the community sums.
  # Incorrect Bcity Sum IFF Groupby keeps a 'False' row (index 56)
  numer.at[55,'count']=numer['count'].sum()

  # Perform the calculation
  fincol = id+'-'+shortname+year
  numer[fincol] = numer['count']

  compareYears = gpd.read_file("https://services1.arcgis.com/mVFRs7NF4iFitgbY/ArcGIS/rest/services/"+shortname.capitalize()+"/FeatureServer/0/query?where=1%3D1&outFields=*&returnGeometry=true&f=pgeojson");
  goback = 2 if year == '19' else 3
  prevYear = shortname + str( int(year) - goback )
  if prevYear in compareYears.columns:
    numer = numer.merge( compareYears[['CSA2010', prevYear]], left_on='CSA2010', right_on='CSA2010', how='outer' )
    numer['change'] = numer[fincol] - numer[ prevYear ]
    numer['percentChange'] = numer['change' ] / numer[ prevYear ] * 100
    numer['change'] = numer['change'].apply(lambda x: "{:.2f}".format(x) )
    print( 'Records Matching Query: ', numer.size / len(numer.columns) )
  return numer.drop(columns=['daysattend', 'daysabsent', 'race_AIAN', 'race_asian', 'race_AA', 'race_NHPI', 'race_white', 'std_number', 'enterdate'])


# AUTOGENERATED! DO NOT EDIT! File to edit: notebooks/Mdprop_Permits_Fore_Vac Vio.ipynb (unless otherwise specified).

__all__ = ['totalres', 'totalres', 'totalres', 'totalres', 'totalres', 'totalres', 'ownroc', 'ownroc', 'ownroc',
           'ownroc', 'ownroc', 'ownroc', 'ownroc', 'ownroc', 'vacantsCsa', 'vacantsCsa', 'vacantsCsa', 'vacantsCsa',
           'vacantsCsa', 'baltvac', 'baltvac', 'baltvac', 'baltvac', 'baltvac', 'baltvac', 'vio', 'vio', 'start_date',
           'end_date', 'mask', 'mask1', 'mask2', 'vio', 'vio', 'vio', 'fore', 'fore', 'fore', 'resrehab', 'use',
           'resrehab', 'resrehab', 'resrehab', 'resrehab', 'demper', 'filter', 'demper', 'demper', 'demper', 'demper',
           'use', 'constper', 'constper', 'constper', 'constper', 'constper', 'constper', 'comprop', 'comprop',
           'comprop', 'comprop', 'comprop', 'crehab', 'crehab', 'crehab', 'crehab', 'crehab', 'crehab', 'crehab']

# Cell
totalres = mdprop.copy()

totalres['totalres'+year] = 1
totalres = totalres[ totalres['DESCLU'].isin(['Apartments', 'Residential', 'Residential Commercial', 'Residential Condominium']) ]
totalres = totalres[ totalres['ADDRESS'].notna() ]
print(totalres.ADDRESS.unique() )
totalres = totalres[['CSA2010','totalres'+year]]
totalres = totalres.groupby('CSA2010').sum(numeric_only=True)
# Make sure ALL csas and BaltimoreCity are included. among other things
totalres = csa[ ['CSA2010','tpop10'] ].merge( totalres, left_on='CSA2010', right_on='CSA2010', how='outer' )
# Update the baltimore CSA.
totalres.at[55,'totalres'+year] = totalres['totalres'+year].sum()

# Create the Indicator
totalres.to_csv('37-totalres-'+year+'.csv', index=False)

totalres.head(58)

# Cell
import datetime
ownroc = mdprop.copy()

ownroc = ownroc[ ownroc['OOI']=='H']
ownroc = ownroc.dropna( subset=['ADDRESS'] )
ownroc = ownroc[ ownroc['DESCLU'].isin(['Apartments', 'Residential', 'Residential Commercial', 'Residential Condominium']) ]
ownroc.to_csv('ownroc'+str(year)+'_Filtered_Records.csv', index=False)

print( 'Records Matching Query: ', ownroc.size / len(ownroc.columns) )

# Aggregate Numeric Values by Sum
ownroc['ownrocCount'] = 1
ownroc = ownroc.groupby('CSA2010').sum(numeric_only=True)
ownroc = csa[ ['CSA2010'] ].merge( ownroc, left_on='CSA2010', right_on='CSA2010', how='outer' )
ownroc = csa.merge( ownroc, left_on='CSA2010', right_on='CSA2010', how='outer' )

# Create the Indicator
ownroc['ownroc'] = ownroc['ownrocCount'] * 100 / totalres['totalres'+year]
ownroc.at[55,'ownrocCount'] = ownroc['ownrocCount'].sum()
ownroc.at[55,'ownroc'] = ownroc['ownrocCount'].sum() * 100/ totalres['totalres'+year].sum()
ownroc = ownroc[ ['CSA2010', 'ownrocCount', 'ownroc'] ]
ownroc.to_csv('32-ownroc'+year+'.csv', index=False)

ownroc.tail(60)

# Cell
import datetime
vacantsCsa = vacants.copy()

# (datenotice between '2004-01-01' and '2016-12-31') AND
# (dateabate is NULL OR dateabate >= '2016-12-31') AND
# (datecancel is NULL OR datecancel > '2016-12-31')

vacantsCsa['DateNotice2'] = pd.to_datetime(vacantsCsa['DateNotice'],infer_datetime_format=True)
vacantsCsa = vacantsCsa[
    ( vacantsCsa['DateNotice2']>=pd.Timestamp(2000+int(year)-13,1,1) ) &
    ( vacantsCsa['DateNotice2']<=pd.Timestamp(2000+int(year),12,31) )
]

vacantsCsa.to_csv('vacants_Filtered_Records.csv', index=False)

print( 'Records Matching Query: ', vacantsCsa.size / len(vacantsCsa.columns) )

# Aggregate Numeric Values by Sum
vacantsCsa['vacantsCount'] = 1
vacantsCsa = vacantsCsa.groupby('CSA2010').sum(numeric_only=True)
vacantsCsa = totalres[ ['CSA2010', 'totalres'+year] ].merge( vacantsCsa, left_on='CSA2010', right_on='CSA2010', how='outer' )

# Create the Indicator
vacantsCsa['vacants'+year] = vacantsCsa['vacantsCount'] * 100 / totalres['totalres'+year]
vacantsCsa.at[55,'vacantsCount'] = vacantsCsa['vacantsCount'].sum()
vacantsCsa.at[55,'vacants'+year] = vacantsCsa['vacantsCount'].sum() * 100 / totalres['totalres'+year].sum()
vacantsCsa = vacantsCsa[ ['CSA2010', 'vacantsCount', 'vacants'+year, 'totalres'+year ] ]
vacantsCsa.to_csv('34-vacants'+year+'.csv', index=False)

vacantsCsa.tail(60)

# Cell
import datetime
baltvac = vacants.copy()

baltvac = baltvac[ (baltvac['OwnerAbbr'].str.contains('DHCD|HABC|HUD|MCC|USA', regex=True, na=False) ) ]
baltvac['DateNotice2'] = pd.to_datetime(baltvac['DateNotice'],infer_datetime_format=True)
baltvac = baltvac[
    ( baltvac['DateNotice2']>=pd.Timestamp(2000+int(year)-13,1,1) ) &
    ( baltvac['DateNotice2']<=pd.Timestamp(2000+int(year),12,31) )
]

baltvac.to_csv('baltvac_Filtered_Records.csv', index=False)

print( 'Records Matching Query: ', baltvac.size / len(baltvac.columns) )

# Aggregate Numeric Values by Sum
baltvac['baltvacCount'] = 1
baltvac = baltvac.groupby('CSA2010').sum(numeric_only=True)
baltvac = vacantsCsa[ ['CSA2010', 'vacants'+year] ].merge( baltvac, left_on='CSA2010', right_on='CSA2010', how='outer' )

# Create the Indicator
baltvac['baltvac'+year] = baltvac['baltvacCount'] / vacantsCsa['vacantsCount'] * 100
baltvac.at[55,'baltvacCount'] = baltvac['baltvacCount'].sum()
baltvac.at[55,'baltvac'+year] = baltvac['baltvacCount'].sum() * 100 / vacantsCsa['vacantsCount'].sum()
baltvac = baltvac[ ['CSA2010', 'baltvacCount', 'baltvac'+year, 'vacants'+year ] ]
baltvac.to_csv('43-baltvac'+year+'.csv', index=False)

baltvac.tail(60)

# Cell
# Numerator
vio = violations.copy()

# drop null
vio['DateCancel'] = pd.to_datetime(vio['DateCancel'])
vio['DateAbate'] = pd.to_datetime(vio['DateAbate'])
vio['DateNotice'] = pd.to_datetime(vio['DateNotice'], errors='coerce')

# Numerator
vio = vio[['DateNotice', 'DateAbate', 'DateCancel','CSA2010']]
vio.head(1)

start_date = '20'+year+'-01-01'
end_date = '20'+year+'-12-31'

mask = vio[ ( vio['DateNotice'] > start_date ) & ( vio['DateNotice'] <= end_date) ]
mask1 = mask[ ( pd.isnull( mask['DateAbate'] ) ) | ( mask['DateAbate'] >= end_date ) ]
mask2 = mask1[ pd.isnull( mask1['DateCancel'] ) | ( mask1['DateCancel'] > end_date ) ]
vio = mask2.copy()

vio.to_csv('vio_Filtered_Records.csv', index=False)

# Cell
# Aggregate Numeric Values by Sum
vio['vioCount'] = 1
vio = vio.groupby('CSA2010').sum(numeric_only=True)
vio = totalres[ ['CSA2010', 'totalres'+year] ].merge( vio, left_on='CSA2010', right_on='CSA2010', how='outer' )

# Create the Indicator
vio['vio'] = vio['vioCount'] * 100 / totalres['totalres'+year]

# Create Baltimore's Record.
vio.at[55,'vioCount'] = vio['vioCount'].sum()
vio.at[55,'vio'] = vio['vioCount'].sum() * 100 / totalres['totalres'+year].sum()

vio.to_csv('35-violations'+year+'.csv', index=False)

vio.tail()

# Cell
# Aggregate Numeric Values by Sum
forclosure['foreCount'] = 1
fore = forclosure.groupby('CSA2010').sum(numeric_only=True)
# Make sure ALL csas and BaltimoreCity are included. among other things
fore = totalres[ ['CSA2010', 'totalres'+year] ].merge( fore, left_on='CSA2010', right_on='CSA2010', how='outer' )

# Create the Indicator
fore['fore'] = fore['foreCount'] * 100 / fore['totalres'+year]

fore.at[55,'foreCount'] = fore['foreCount'].sum()
fore.at[55,'fore'] = fore['foreCount'].sum() * 100 / fore['totalres'+year].sum()

fore = fore[['CSA2010', 'foreCount', 'fore', 'totalres'+year ]]

fore.to_csv('33-fore'+year+'.csv', index=False)

fore.tail(60)

# Cell
resrehab = permitsCsa
resrehab['Field22'] = resrehab['typework']

use = ".SF.|.MF.|.DFAM.|.1-.|SF|MF|DFAM|1-.|.1-"
resrehab = resrehab[
  ( permitsCsa['existingus'].str.contains(use, regex=True, na=False) ) &
  ( permitsCsa['propuse'].str.contains(use, regex=True, na=False) ) &
  ( permitsCsa['casetype'].str.contains('.COM.|COM', regex=True, na=False) ) &
  ( permitsCsa['Field22'].str.contains('.AA.|.ADD.|.ALT.|AA|ADD|ALT|ADD', regex=True, na=False) ) &
  ( permitsCsa['cost'] >=5000 )
]

resrehab.to_csv('resrehab'+year+'_Filtered_Records.csv', index=False)

print( 'Records Matching Query: ', resrehab.size / len(resrehab.columns) )

# Aggregate Numeric Values by Sum
resrehab['resrehabCount'] = 1
resrehab = resrehab.groupby('CSA2010').sum(numeric_only=True)

# Make sure ALL csas and BaltimoreCity are included. among other things
resrehab = totalres[ ['CSA2010','totalres'+year] ].merge( resrehab, left_on='CSA2010', right_on='CSA2010', how='outer' )

# Update the baltimore CSA.
resrehab.at[55,'resrehabCount'] = resrehab['resrehabCount'].sum()

# Create the Indicator
resrehab['resrehab'+year] = resrehab['resrehabCount'] * 100 / totalres['totalres'+year]

resrehab = resrehab[ ['CSA2010', 'resrehabCount', 'resrehab'+year, 'totalres'+year ] ]

resrehab.to_csv('36-resrehab'+year+'.csv', index=False)

resrehab.head()
resrehab.tail()

# Cell
demper = permitsCsa[
  ( permitsCsa['casetype'].str.contains('DEM|.DEM.|DEM.|.DEM', regex=True, na=False) )
]

filter = demper["PLANADDRES"] != ""
demper = demper[filter]


demper.to_csv('demper'+year+'_Filtered_Records.csv', index=False)

print( 'Records Matching Query: ', demper.size / len(demper.columns) )


# Aggregate Numeric Values by Sum
demper['demperCount'] = 1
demper = demper.groupby('CSA2010').sum(numeric_only=True)

# Make sure ALL csas and BaltimoreCity are included. among other things
demper = totalres[ ['CSA2010','totalres'+year] ].merge( demper, left_on='CSA2010', right_on='CSA2010', how='outer' )

# Update the baltimore CSA.
demper.at[55,'demperCount'] = demper['demperCount'].sum()

# Create the Indicator
demper['demper'+year] = demper['demperCount'] * 100 / totalres['totalres'+year]

# Create the Indicator
demper['demper'+year] = demper['demperCount'] * 1000 / totalres['totalres'+year]

demper = demper[['CSA2010', 'demperCount', 'demper'+year, 'totalres'+year ]]

demper.to_csv('41-demper'+year+'.csv', index=False)

demper.head(60)

# Cell
# 2018 and 2017 is not working with the new datasets given (CSA LABELS)

use = "SF|MF|.SF.|.MF.|.SF|.MF|SF.|MF."
constper = permitsCsa
constper['Field22'] = constper['typework']
constper = constper[
  #(
  #    permitsCsa['existingus'].str.contains(use, regex=True, na=False) |
  #    permitsCsa['propuse'].str.contains(use, regex=True, na=False)
  #) &
  #( permitsCsa['casetype'].str.contains('COM|.COM.|COM.|.COM', regex=True, na=False) ) &
  ( constper['Field22'].str.contains('NEW|.NEW.|NEW.|.NEW', regex=True, na=False) )
]

constper = constper[constper["PLANADDRES"] != ""]

constper = constper[['CSA2010','existingus','propuse','casetype','Field22','PLANADDRES' ]]

constper.to_csv('constper'+year+'_Filtered_Records.csv', index=False)

print( 'Records Matching Query: ', constper.size / len(constper.columns) )

# Aggregate Numeric Values by Sum
constper['constperCount'] = 1
constper = constper.groupby('CSA2010').sum(numeric_only=True)

# Make sure ALL csas and BaltimoreCity are included. among other things
constper = totalres[ ['CSA2010','totalres'+year] ].merge( constper, left_on='CSA2010', right_on='CSA2010', how='outer' )

# Update the baltimore CSA.
constper.at[55,'constperCount'] = constper['constperCount'].sum()

# Create the Indicator
constper['42-constper'+year] = constper['constperCount'] * 1000 / totalres['totalres'+year]

constper.to_csv('42-constper'+year+'.csv', index=False)

constper.head(80)

# Cell
# sum( case when (lu like 'C' OR lu LIKE 'EC' OR lu LIKE 'I')

comprop = mdprop.copy()
comprop['comprop'+year] = 1
# mdprop = csa[['CSA','comprop19']]
comprop = comprop[ comprop['LU'].isin( ['C','EC','I'] ) ]
comprop = comprop.groupby('CSA2010').sum(numeric_only=True)
# Make sure ALL csas and BaltimoreCity are included. among other things
comprop = csa[ ['CSA2010','tpop10'] ].merge( comprop, left_on='CSA2010', right_on='CSA2010', how='outer' )
# Update the baltimore CSA.
comprop.at[55,'comprop'+year] = comprop['comprop'+year].sum()
comprop = comprop[['comprop'+year, 'CSA2010']]
comprop.head(58)

# Create the Indicator
comprop.to_csv('141-comprop'+year+'.csv', index=False)

# Cell
# get the permits file
crehab = permitsCsa.copy()

# Our Column to Sum on
crehab['crehab'+year] = 1
# Filter 1

print('No Filter:', crehab.shape[0])
print('Filter Cost:', crehab[crehab['cost'] >=5000].cost.shape[0])
print('Filter ExistingUse:', crehab.loc[crehab['existingus'].str.contains('2-|3-|4-|5-|6-|7-|COM|IND|BUS|AIR|ANIM|BAR|BEAU|DELI|FAC|ASM|ALV|DOTH|DWC|EDU|FOOD|HCF|HIH|HOS|MIXC|INS|MER|LIB|MNTL|MOB|PUB|STO|UT|VAC|VAL|DFAM') == True].shape[0])
# print('Filter Propuse:', crehab.loc[ crehab['propuse'].str.contains('COM|IND|BUS|AIR|ANIM|BAR|BEAU|DELI|FAC|ASM|ALV|DOTH|DWC|EDU|FOOD|HCF|HIH|HOS|MIXC|INS|MER|LIB|MNTL|MOB|PUB|STO|UT|DFAM') == True].shape[0])
print('Filter typework:', crehab[  crehab['typework'].isin( ['AA','ALT','ADD'] ) ].shape[0])

crehab.loc[ crehab['propuse'].str.contains('COM|IND|BUS|AIR|ANIM|BAR|BEAU|DELI|FAC|ASM|ALV|DOTH|DWC|EDU|FOOD|HCF|HIH|HOS|MIXC|INS|MER|LIB|MNTL|MOB|PUB|STO|UT|DFAM') == True].propuse.unique()

crehab = crehab.loc[crehab['existingus'].str.contains('2-|3-|4-|5-|6-|7-|COM|IND|BUS|AIR|ANIM|BAR|BEAU|DELI|FAC|ASM|ALV|DOTH|DWC|EDU|FOOD|HCF|HIH|HOS|MIXC|INS|MER|LIB|MNTL|MOB|PUB|STO|UT|VAC|VAL|DFAM') == True]
# crehab = crehab.loc[ crehab['propuse'].str.contains('COM|IND|BUS|AIR|ANIM|BAR|BEAU|DELI|FAC|ASM|ALV|DOTH|DWC|EDU|FOOD|HCF|HIH|HOS|MIXC|INS|MER|LIB|MNTL|MOB|PUB|STO|UT|DFAM') == True]
crehab = crehab[ crehab['cost'] >=5000 ]
crehab = crehab[  crehab['typework'].isin( ['AA','ALT','ADD'] ) ]
crehab.head(1)

# Cell
crehab = crehab.groupby('CSA2010').sum(numeric_only=True)
# Make sure ALL csas and BaltimoreCity are included. among other things
crehab = csa[ ['CSA2010','tpop10'] ].merge( crehab, left_on='CSA2010', right_on='CSA2010', how='outer' )
# Update the baltimore CSA.
crehab.at[55,'crehab'+year] = crehab['crehab'+year].sum()
crehab = crehab[['crehab'+year, 'CSA2010']]
crehab['crehab'+year] = crehab['crehab'+year] *100 / comprop['comprop'+year]

crehab.head(58)

# Create the Indicator
crehab.to_csv('142-crehab'+year+'.csv', index=False)